@@ -7,6 +7,7 @@ import (
 	"net"
 	"strings"
 
+	dockertypes "github.com/docker/docker/api/types"
 	"github.com/docker/go-connections/nat"
 	"github.com/traefik/traefik/v2/pkg/config/dynamic"
 	"github.com/traefik/traefik/v2/pkg/config/label"
@@ -73,11 +74,13 @@ func (p *Provider) buildConfiguration(ctx context.Context, containersInspected [
 		serviceName := getServiceName(container)
 
 		model := struct {
-			Name   string
-			Labels map[string]string
+			Name          string
+			ContainerName string
+			Labels        map[string]string
 		}{
-			Name:   serviceName,
-			Labels: container.Labels,
+			Name:          serviceName,
+			ContainerName: strings.TrimPrefix(container.Name, "/"),
+			Labels:        container.Labels,
 		}
 
 		provider.BuildRouterConfiguration(ctx, confFromLabel.HTTP, serviceName, p.defaultRuleTpl, model)
@@ -100,10 +103,13 @@ func (p *Provider) buildTCPServiceConfiguration(ctx context.Context, container d
 		}
 	}
 
+	if container.Health != "" && container.Health != dockertypes.Healthy {
+		return nil
+	}
+
 	for name, service := range configuration.Services {
-		ctxSvc := log.With(ctx, log.Str(log.ServiceName, name))
-		err := p.addServerTCP(ctxSvc, container, service.LoadBalancer)
-		if err != nil {
+		ctx := log.With(ctx, log.Str(log.ServiceName, name))
+		if err := p.addServerTCP(ctx, container, service.LoadBalancer); err != nil {
 			return fmt.Errorf("service %q error: %w", name, err)
 		}
 	}
@@ -116,16 +122,18 @@ func (p *Provider) buildUDPServiceConfiguration(ctx context.Context, container d
 
 	if len(configuration.Services) == 0 {
 		configuration.Services = make(map[string]*dynamic.UDPService)
-		lb := &dynamic.UDPServersLoadBalancer{}
 		configuration.Services[serviceName] = &dynamic.UDPService{
-			LoadBalancer: lb,
+			LoadBalancer: &dynamic.UDPServersLoadBalancer{},
 		}
 	}
 
+	if container.Health != "" && container.Health != dockertypes.Healthy {
+		return nil
+	}
+
 	for name, service := range configuration.Services {
-		ctxSvc := log.With(ctx, log.Str(log.ServiceName, name))
-		err := p.addServerUDP(ctxSvc, container, service.LoadBalancer)
-		if err != nil {
+		ctx := log.With(ctx, log.Str(log.ServiceName, name))
+		if err := p.addServerUDP(ctx, container, service.LoadBalancer); err != nil {
 			return fmt.Errorf("service %q error: %w", name, err)
 		}
 	}
@@ -145,10 +153,13 @@ func (p *Provider) buildServiceConfiguration(ctx context.Context, container dock
 		}
 	}
 
+	if container.Health != "" && container.Health != dockertypes.Healthy {
+		return nil
+	}
+
 	for name, service := range configuration.Services {
-		ctxSvc := log.With(ctx, log.Str(log.ServiceName, name))
-		err := p.addServer(ctxSvc, container, service.LoadBalancer)
-		if err != nil {
+		ctx := log.With(ctx, log.Str(log.ServiceName, name))
+		if err := p.addServer(ctx, container, service.LoadBalancer); err != nil {
 			return fmt.Errorf("service %q error: %w", name, err)
 		}
 	}
@@ -174,7 +185,7 @@ func (p *Provider) keepContainer(ctx context.Context, container dockerData) bool
 		return false
 	}
 
-	if container.Health != "" && container.Health != "healthy" {
+	if !p.AllowEmptyServices && container.Health != "" && container.Health != dockertypes.Healthy {
 		logger.Debug("Filtering unhealthy or starting container")
 		return false
 	}
@@ -299,6 +310,7 @@ func (p *Provider) getIPPort(ctx context.Context, container dockerData, serverPo
 func (p Provider) getIPAddress(ctx context.Context, container dockerData) string {
 	logger := log.FromContext(ctx)
 
+	netNotFound := false
 	if container.ExtraConf.Docker.Network != "" {
 		settings := container.NetworkSettings
 		if settings.Networks != nil {
@@ -307,7 +319,8 @@ func (p Provider) getIPAddress(ctx context.Context, container dockerData) string
 				return network.Addr
 			}
 
-			logger.Warnf("Could not find network named '%s' for container '%s'! Maybe you're missing the project's prefix in the label? Defaulting to first available network.", container.ExtraConf.Docker.Network, container.Name)
+			netNotFound = true
+			logger.Debugf("Could not find network named %q for container %q. Maybe you're missing the project's prefix in the label?", container.ExtraConf.Docker.Network, container.Name)
 		}
 	}
 
@@ -318,6 +331,9 @@ func (p Provider) getIPAddress(ctx context.Context, container dockerData) string
 		if host, err := net.LookupHost("host.docker.internal"); err == nil {
 			return host[0]
 		}
+		if host, err := net.LookupHost("host.containers.internal"); err == nil {
+			return host[0]
+		}
 		return "127.0.0.1"
 	}
 
@@ -353,6 +369,9 @@ func (p Provider) getIPAddress(ctx context.Context, container dockerData) string
 	}
 
 	for _, network := range container.NetworkSettings.Networks {
+		if netNotFound {
+			logger.Warnf("Defaulting to first available network (%q) for container %q.", network, container.Name)
+		}
 		return network.Addr
 	}
 
